# UI/UX Feedback

**ID:** Feedback-20260301-155900
**URL:** http://127.0.0.1:5858/
**Date:** 2026-03-01 16:02:54

## Selected Elements

- `{'selector': '#wf-create-name', 'parents': ['div.workflow-modal-overlay', 'div.workflow-modal']}`

## Feedback

workflow need to support Chinese Name, when we create idea, it also need to support chinese name, and if any physical folder need to be created, it should also support chinese

## Screenshot

![Screenshot](x-ipe-docs/uiux-feedback/Feedback-20260301-155900-1/page-screenshot.png)
